pub struct ViewState {
pub is_break: bool,
pub is_postponed: bool,
pub postpone_count: u16,
pub round: u64,
pub time: String,
pub is_paused: bool,
}Expand description
Information that will be handed to the [on_tick] closure continously
Fields
is_break: boolDenotes if the current timer is a break timer
is_postponed: boolDenotes if the timer is currently in a postponed state or not
postpone_count: u16Denotes how often the current timer has already been postponed
round: u64Denotes the current interval round
time: StringDenotes the current time of the timer
is_paused: boolDenotes if the timer is currently paused